/* $Header:   U:/engineer/sw/t2r/filelib/number.c_v   1.0   05 Nov 1992 17:04:30   galen  $
 */
#include "number9.h"

/* Number theoretic function - GCD (Greatest Common Divisor) */
long
n9gcd(a, b)
register long a, b;
{
  register long c = a % b;
  while (c)
    a = b, b = c, c = a % b;
  return b;
}

