/* number9.h - functions needed to set the programmable clock generator in
   the Number 9 GXE graphics card (S3 928 based) */

extern long n9calc_clock(long, int);
extern long n9set_clock(long);
extern long n9get_clock(long);
extern long n9gcd(long, long);
